@@ -3,6 +3,7 @@
 import glob
 import re
 import itertools
+import pytest
 import ansibleext.general_utils as utils
 from ansibleext.inventory_base import InventoryBase
 from typing import Dict, Any
@@ -12,6 +13,16 @@ def intersect_dicts(d1: Dict[Any, Any], d2: Dict[Any, Any]):
     return {k: v for k, v in d1.items() if k in d2.keys()}
 
 
+'''
+Fixture based InventoryBase.
+'''
+@pytest.fixture(scope="module")
+def inventory_base():
+    inv_base = InventoryBase()
+    inv_base.setUp()
+    return inv_base
+
+
 class InventoryLoadable(InventoryBase):
 
     def runTest(self):
@@ -212,8 +223,7 @@ class InventoryHardwareGroupsConsistent(InventoryBase):
                                 'jenkins', 'jenkins_fedtest', 'jenkins_tablettest',
                                 'hw_test_automation',
                                 'promtail',
-                                'nonclusterspecific',
-                                'bond_detect_mode_carrier')
+                                'nonclusterspecific')
                 if group in allowedGroups:
                     continue
                 contains = utils.containsAtLeastOneSubstring(group, ('hwn', 'lxc', 'openvz'));
@@ -272,3 +282,30 @@ class LxcHostHasValidPreferences(InventoryBase):
                 parent_host = self.getVariable(inventory, host, 'parent')
                 if parent_host:
                     self.fail(f'no lxc_zfsroot_type configured for {host}, but it has parent {parent_host}')
+
+
+@pytest.fixture(scope="module")
+def all_hosts(inventory_base) -> set[str]:
+    return set([host.get_name() for _, host in inventory_base.inventories_hosts()])
+
+@pytest.fixture(scope="module")
+def all_groups_with_at_least_one_host(inventory_base) -> set[str]:
+    existing_groups: set[str] = set()
+    for inventory, host in inventory_base.inventories_hosts():
+        groups = inventory_base.getGroups(inventory, host)
+        existing_groups.update(groups)
+    return existing_groups
+
+@pytest.mark.parametrize("path", glob.glob('*', root_dir='host_vars'))
+def test_HostVarsContainsOnlyFilesForHostsWhichExist(path, all_hosts):
+    host_name = path.removesuffix('.yml')
+    if host_name in ['localhost']:
+        return
+    assert host_name in all_hosts, f"file host_vars/{path} does not correspond with an existing host in any inventory"
+
+@pytest.mark.parametrize("path", glob.glob('*', root_dir='group_vars'))
+def test_GroupVarsContainsOnlyFilesForGroupsWhichHaveAtLeastOneHost(path, all_groups_with_at_least_one_host):
+    group_name = path.removesuffix('.yml')
+    if group_name in ['all', 'jenkins_java_hetzner']:
+        return
+    assert group_name in all_groups_with_at_least_one_host, f"file group_vars/{path} does not correspond with a group with any host in any inventory"
